@@ -18,15 +18,23 @@ opts_chunk$set(
 #  source("https://bioconductor.org/biocLite.R")
 #  biocLite("RTCGA.clinical") # data for examples
 
-## ---- fig.width=10----------------------------------------------------------------------------------------------------------------------------------
+## ---- fig.width=10, eval = FALSE--------------------------------------------------------------------------------------------------------------------
+#  library(survminer)
+#  library(RTCGA.clinical)
+#  survivalTCGA(BRCA.clinical, OV.clinical,
+#               extract.cols = "admin.disease_code") -> BRCAOV.survInfo
+#  library(survival)
+#  fit <- survfit(Surv(times, patient.vital_status) ~ admin.disease_code,
+#                 data = BRCAOV.survInfo)
+#  # Visualize with survminer
+#  ggsurvplot(fit, data = BRCAOV.survInfo, risk.table = TRUE)
+
+## ---- echo = FALSE, fig.width=10--------------------------------------------------------------------------------------------------------------------
 library(survminer)
-library(RTCGA.clinical)
-survivalTCGA(BRCA.clinical, OV.clinical,
-             extract.cols = "admin.disease_code") -> BRCAOV.survInfo
+data(BRCAOV.survInfo)
 library(survival)
 fit <- survfit(Surv(times, patient.vital_status) ~ admin.disease_code,
                data = BRCAOV.survInfo)
-# Visualize with survminer
 ggsurvplot(fit, data = BRCAOV.survInfo, risk.table = TRUE)
 
 ## ---- fig.width=10----------------------------------------------------------------------------------------------------------------------------------
@@ -40,7 +48,7 @@ ggsurvplot(
    xlim = c(0,2000),        # present narrower X axis, but not affect
                             # survival estimates.
    break.time.by = 500,     # break X axis in time intervals by 500.
-   ggtheme = theme_RTCGA(), # customize plot and risk table with a theme.
+   ggtheme = theme_minimal(), # customize plot and risk table with a theme.
  risk.table.y.text.col = T, # colour risk table text annotations.
   risk.table.y.text = FALSE # show bars instead of names in text annotations
                             # in legend of risk table
@@ -69,10 +77,10 @@ survMisc:::autoplot.survfit( # with some hard customization
    pVal=TRUE
 ) -> fit.survMisc 
 fit.survMisc$table <- fit.survMisc$table +
-   theme_RTCGA() + # theme(legend.position = "top")
+   theme_minimal() + # theme(legend.position = "top")
    coord_cartesian(xlim = c(0,2000))
 fit.survMisc$plot <- fit.survMisc$plot +
-   theme_RTCGA() + 
+   theme_minimal() + 
    coord_cartesian(xlim = c(0,2000))
 survMisc:::print.tableAndPlot(fit.survMisc)
 
